@@ -22,14 +22,14 @@ class TitleBar : public QWidget
 
 public:
     explicit TitleBar(MainWindow *mainWindow);
-    ~TitleBar();
+    ~TitleBar() override;
 
     void setVisible(bool visible) override;
     void applySkin();
     void updateMask();
     void updateMenu();
 
-    QString title();
+    QString title() const;
 
     void setFocusButtonState(bool checked);
 
@@ -44,13 +44,13 @@ protected:
 private:
     void moveButtons();
 
-    MainWindow *m_mainWindow;
-    Skin *m_skin;
+    MainWindow *m_mainWindow = nullptr;
+    Skin *m_skin = nullptr;
     bool m_visible = false;
 
-    QPushButton *m_focusButton;
-    QPushButton *m_menuButton;
-    QPushButton *m_quitButton;
+    QPushButton *m_focusButton = nullptr;
+    QPushButton *m_menuButton = nullptr;
+    QPushButton *m_quitButton = nullptr;
 
     QString m_title;
 };
